==> yiff_2.06.orig.tar.gz: yiff-2.06/yiffutils/yhost.c <==
#include <stdio.h>
#include <stdlib.h>
#include <malloc.h>
#include <string.h>

#include <sys/types.h>
#include <sys/socket.h>

#include <netdb.h>	/* For gethostbyname(). */
extern int h_errno;

#include <netinet/in.h>

#include <Y2/Y.h>
#include <Y2/Ylib.h>

#include "../include/string.h"


#ifndef DEF_CON_ARG
# define DEF_CON_ARG    "127.0.0.1:9433"
#endif            



/*
 *	Print help.
 */
void PrintUsage()
{
	printf("\
Usage: yhost [-] <address> [options]\n\
\n\
    Specifying a `-' argument means to remove the <address>.\n\
\n\
    <address> is the numeric IP or named address of the host you\n\
    want to allow/disallow access to the YIFF server.\n\
    This command must be runned on the same physical computer as\n\
    the YIFF server is running on.\n\
\n\
    [options] can be any of the following:\n\
\n\
        --recorder <address:port>    Specify which YIFF server to connect to.\n\
\n"
	);


	return;
}


int main(int argc, char *argv[])
{
	int i, status;

	char *con_arg = NULL;

	int op = 1;

	YConnection *con = NULL;
	YIPUnion ip;

	struct hostent *he;
        struct sockaddr_in haddr;


	if(argc < 2)
	{
	    PrintUsage();
	    return(1);
	}


	/* Parse arguments. */
	for(i = 1; i < argc; i++)
	{
	    if(argv[i] == NULL)
		continue;

	    /* Help. */
	    if(strcasepfx(argv[i], "--h") ||
               strcasepfx(argv[i], "-h") ||
               !strcmp(argv[i], "?")
	    )
	    {
		PrintUsage();
		return(0);
	    }

	    /* Add or remove? */
	    if(i == 1)
	    {
		if(!strcmp(argv[i], "-"))
		{
		    op = 0;	/* We know it's remove, continue. */
		    continue;
		}
		else if(!strcmp(argv[i], "+"))
		{
		    op = 1;	/* We know it's add, continue. */
                    continue;
		}
		else
		{
		    op = 1;
		}
	    }

	    /* Address. */
	    if((i == 1) ||
               (i == 2)
            )
	    {
		/* Parse address. */
		he = gethostbyname(argv[i]);
		if(he == NULL)
		{
		    switch(h_errno)
		    {
                      case NO_ADDRESS:
                        fprintf(stderr,
                            "%s: No associated IP address.\n",
                            argv[i]
                        );
                        break;

                      case NO_RECOVERY:
                        fprintf(stderr,
                            "%s: Unrecoverable error.\n",
                            argv[i]
                        );
                        break;

                      case TRY_AGAIN:
                        fprintf(stderr,
                            "%s: Name server unavailable.\n",
                            argv[i]
                        );
                        break;

                      default:
                        fprintf(stderr,
                            "%s: Unknown host.\n",
                            argv[i]
                        );
                        break;
		    }

		    free(con_arg);
		    con_arg = NULL;

		    return(1);
		}

		haddr.sin_addr = *((struct in_addr *)he->h_addr);
		ip.whole = (u_int32_t)haddr.sin_addr.s_addr;

		continue;
	    }

	    /* Connect address. */
	    if(strcasepfx(argv[i], "--rec") ||
               strcasepfx(argv[i], "-rec")
	    )
	    {
		i++;
		if(i < argc)
		{
		    free(con_arg);
		    con_arg = StringCopyAlloc(argv[i]);
		}
		else
		{
		    fprintf(stderr,
			"%s: Requires argument.\n",
			argv[i - 1]
		    );
		}
	    }
	}


	/*
	 *	Connect to YIFF server.
	 */
	con = YOpenConnection(
	    NULL,		/* No start argument. */
	    con_arg
	);
	if(con == NULL)
	{
	    printf("%s: Cannot connect to YIFF server.\n",
		(con_arg == NULL) ? DEF_CON_ARG : con_arg
	    );

            free(con_arg);
            con_arg = NULL;

	    return(-1);
	}


	/*
	 *	Add or remove host.
	 */
	if(op)
	    status = YAddHost(con, &ip);
	else
	    status = YRemoveHost(con, &ip);        

	if(status)
            printf("Cannot %s %i.%i.%i.%i.\n",
		(op == 0) ? "remove" : "add",
                ip.charaddr[0],
                ip.charaddr[1],
                ip.charaddr[2],
                ip.charaddr[3]
            );
	else
            printf("%s %i.%i.%i.%i %s host access list.\n",
                ((op == 0) ? "Removing" : "Adding"),
                ip.charaddr[0],
                ip.charaddr[1],
                ip.charaddr[2],
                ip.charaddr[3],
		((op == 0) ? "from" : "to")
            );

	/*
	 *	Disconnect from YIFF server
	 */
	YCloseConnection(con, False);
	con = NULL;

	free(con_arg);
	con_arg = NULL;



	return(0);
}

==> yiff_2.12.4.orig.tar.gz: yiff2.12.4/yiffutils/yhost.c <==
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <sys/types.h>
#include <sys/socket.h>

#include <netdb.h>	/* For gethostbyname(). */
extern int h_errno;

#include <netinet/in.h>

#include "../include/Y2/Y.h"
#include "../include/Y2/Ylib.h"

#include "../include/string.h"


static void print_help(void);


/*
 *	Prints help message.
 */
static void print_help(void)
{
	printf("\
Usage: yhost [-] <address> [options]\n\
\n\
    Specifying a `-' argument means to remove the <address>.\n\
\n\
    <address> is the numeric IP or named address of the host you\n\
    want to allow/disallow access to the Y server.\n\
    This command must be runned on the same physical computer as\n\
    the Y server is running on.\n\
\n\
    [options] can be any of the following:\n\
\n\
        --recorder <address:port>    Specify which Y server to connect to.\n\
\n\
    Return values:\n\
\n\
        0       Success.\n\
        1       General error.\n\
        2       Cannot connect to Y server error.\n\
        3       Systems error.\n\
\n"
	);

	return;
}


int main(int argc, char *argv[])
{
	int i, status;
	const char *con_arg = NULL;
	int is_add_host = 1;

	YConnection *con = NULL;
	YIPUnion ip;

	struct hostent *he;
        struct sockaddr_in haddr;


	if(argc < 2)
	{
	    print_help();
	    return(1);
	}


	/* Parse arguments. */
	for(i = 1; i < argc; i++)
	{
	    if(argv[i] == NULL)
		continue;

	    /* Help. */
	    if(strcasepfx(argv[i], "--h") ||
               strcasepfx(argv[i], "-h") ||
               !strcmp(argv[i], "?")
	    )
	    {
		print_help();
		return(0);
	    }
            /* Connect address. */
            if(strcasepfx(argv[i], "--rec") ||
               strcasepfx(argv[i], "-rec")
            )
            {
                i++;
                if(i < argc)
                {
                    con_arg = argv[i];
                }
                else
                {
                    fprintf(stderr,
                        "%s: Requires argument.\n",
                        argv[i - 1]
                    );
                }
            }
	    /* Add or remove? */
	    if(i == 1)
	    {
		if(!strcmp(argv[i], "-"))
		{
		    is_add_host = 0;
		    continue;
		}
		else if(!strcmp(argv[i], "+"))
		{
		    is_add_host = 1;
                    continue;
		}
		else
		{
		    is_add_host = 1;
		}
	    }
	    /* Address. */
	    if((i == 1) ||
               (i == 2)
            )
	    {
		/* Parse and resolve address. */
		he = gethostbyname(argv[i]);
		if(he == NULL)
		{
		    switch(h_errno)
		    {
                      case NO_ADDRESS:
                        fprintf(stderr,
                            "%s: No associated IP address.\n",
                            argv[i]
                        );
                        break;

                      case NO_RECOVERY:
                        fprintf(stderr,
                            "%s: Unrecoverable error.\n",
                            argv[i]
                        );
                        break;

                      case TRY_AGAIN:
                        fprintf(stderr,
                            "%s: Name server unavailable.\n",
                            argv[i]
                        );
                        break;

                      default:
                        fprintf(stderr,
                            "%s: Unknown host.\n",
                            argv[i]
                        );
                        break;
		    }

		    return(1);
		}

		haddr.sin_addr = *((struct in_addr *)he->h_addr);
		ip.whole = (u_int32_t)haddr.sin_addr.s_addr;

		continue;
	    }
	}


        /* Connect to Y server. */
        con = YOpenConnection(
            NULL,               /* No start argument. */
            con_arg
        );
        if(con == NULL)
        {
            fprintf(stderr, "Cannot connect to Y server");
            if(con_arg == NULL)
                con_arg = getenv("RECORDER");
            if(con_arg == NULL)
                fprintf(stderr, ".\n");
            else
                fprintf(stderr, ": %s\n", con_arg);
            return(2);
        }

	/* Add or remove host? */
	if(is_add_host)
	    status = YAddHost(con, &ip);
	else
	    status = YRemoveHost(con, &ip);

	if(status)
            printf("Cannot %s %i.%i.%i.%i.\n",
		(is_add_host) ? "add" : "remove",
                ip.charaddr[0],
                ip.charaddr[1],
                ip.charaddr[2],
                ip.charaddr[3]
            );
	else
            printf("%s %i.%i.%i.%i %s host access list.\n",
                (is_add_host) ? "Adding" : "Removing",
                ip.charaddr[0],
                ip.charaddr[1],
                ip.charaddr[2],
                ip.charaddr[3],
		(is_add_host) ? "to" : "from"
            );

        /* Disconnect from Y server. */
        YCloseConnection(con, False);
        con = NULL;

	return(0);
}
